@@ -53,8 +53,8 @@ finalize (GObject *object)
 		return;
 	}
 
- 	if (disclosure->priv->expand_id > 0)
-		g_source_remove (disclosure->priv->expand_id);
+	g_free (disclosure->priv->hidden);
+	g_free (disclosure->priv->shown);
 
 	if (disclosure->priv->container != NULL) {
 		g_object_unref (G_OBJECT (disclosure->priv->container));
@@ -67,16 +67,12 @@ finalize (GObject *object)
 }
 
 static void
-unrealize (GtkWidget *widget)
+cddb_disclosure_destroy (GtkObject *obj)
 {
-	CDDBDisclosure *disclosure;
+	CDDBDisclosure *disclosure = CDDB_DISCLOSURE (obj);
 
-	disclosure = CDDB_DISCLOSURE (widget);
-
-	if (disclosure->priv->expand_id > 0) {
+	if (disclosure->priv->expand_id)
 		g_source_remove (disclosure->priv->expand_id);
-		disclosure->priv->expand_id = 0;
-	}
 }
 
 static void
@@ -86,7 +82,7 @@ get_x_y (CDDBDisclosure *disclosure,
 	 GtkStateType *state_type)
 {
 	GtkCheckButton *check_button;
-	int indicator_size = 0;
+	int indicator_size, indicator_spacing;
 	int focus_width;
 	int focus_pad;
 	gboolean interior_focus;
@@ -98,6 +94,11 @@ get_x_y (CDDBDisclosure *disclosure,
 	    GTK_WIDGET_MAPPED (disclosure)) {
 		check_button = GTK_CHECK_BUTTON (disclosure);
 		
+		gtk_widget_style_get (GTK_WIDGET (check_button),
+				      "indicator_size", &indicator_size,
+				      "indicator_spacing", &indicator_spacing,
+				      NULL);
+
 		gtk_widget_style_get (widget,
 				      "interior_focus", &interior_focus,
 				      "focus-line-width", &focus_width,
@@ -111,12 +112,12 @@ get_x_y (CDDBDisclosure *disclosure,
 		}
 
 		if (bin->child) {
-			width = bin->child->allocation.x - widget->allocation.x - (2 * GTK_CONTAINER (widget)->border_width);
+			width = indicator_spacing * 3 + indicator_size ;
 		} else {
-			width = widget->allocation.width;
+			width = widget->allocation.width - 2 * GTK_CONTAINER (widget)->border_width;
 		}
 		
-		*x = widget->allocation.x + (width) / 2;
+		*x = widget->allocation.x + GTK_CONTAINER (widget)->border_width + (width) / 2;
 		*y = widget->allocation.y + widget->allocation.height / 2;
 
 		if (interior_focus == FALSE) {
@@ -126,7 +127,7 @@ get_x_y (CDDBDisclosure *disclosure,
 		*state_type = GTK_WIDGET_STATE (widget) == GTK_STATE_ACTIVE ? GTK_STATE_NORMAL : GTK_WIDGET_STATE (widget);
 
 		if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) {
-			*x = widget->allocation.x + widget->allocation.width - (indicator_size + *x - widget->allocation.x);
+			*x = widget->allocation.x + widget->allocation.width - (*x - widget->allocation.x);
 		}
 	} else {
 		*x = 0;
@@ -166,9 +167,7 @@ expand_collapse_timeout (gpointer data)
 		g_object_set (G_OBJECT (disclosure),
 			      "label", disclosure->priv->hidden,
 			      NULL);
-
-		disclosure->priv->expand_id = 0;
-
+			      
 		return FALSE;
 	} else if ((int) disclosure->priv->style < (int) GTK_EXPANDER_COLLAPSED) {
 		disclosure->priv->style = GTK_EXPANDER_COLLAPSED;
@@ -181,8 +180,6 @@ expand_collapse_timeout (gpointer data)
 			      "label", disclosure->priv->shown,
 			      NULL);
 
-		disclosure->priv->expand_id = 0;
-
 		return FALSE;
 	} else {
 		return TRUE;
@@ -195,8 +192,8 @@ do_animation (CDDBDisclosure *disclosure,
 {
 	if (disclosure->priv->expand_id > 0) {
 		g_source_remove (disclosure->priv->expand_id);
-		disclosure->priv->expand_id = 0;
 	}
+
 	disclosure->priv->direction = opening ? 1 : -1;
 	disclosure->priv->expand_id = g_timeout_add (50, expand_collapse_timeout, disclosure);
 }
@@ -238,6 +235,7 @@ static void
 class_init (CDDBDisclosureClass *klass)
 {
 	GObjectClass *object_class;
+	GtkObjectClass *gtk_object_class = (GtkObjectClass *) klass;
 	GtkWidgetClass *widget_class;
 	GtkCheckButtonClass *button_class;
 	GtkToggleButtonClass *toggle_class;
@@ -252,7 +250,8 @@ class_init (CDDBDisclosureClass *klass)
 
 	object_class->finalize = finalize;
 
-	widget_class->unrealize = unrealize;
+	gtk_object_class->destroy = cddb_disclosure_destroy;
+
 	parent_class = g_type_class_peek_parent (klass);
 
 	gtk_widget_class_install_style_property (widget_class,
