@@ -213,8 +213,7 @@ drawer_widget_close_drawer (DrawerWidget *drawer, GtkWidget *parentp)
 static void
 drawer_pos_hidebutton_click (BasePWidget *basep)
 {
-	Drawer *drawer = g_object_get_data (G_OBJECT (basep),
-					    DRAWER_PANEL_KEY);
+	Drawer *drawer = drawer_widget_get_drawer (DRAWER_WIDGET (basep));
 	PanelWidget *panel = PANEL_WIDGET (drawer->button->parent);
 	GtkWidget *parent = panel->panel_parent;
 
@@ -332,21 +331,21 @@ drawer_pos_pre_convert_hook (BasePWidget *basep)
 }
 
 void
-drawer_widget_change_params (DrawerWidget  *drawer,
-			     int            screen,
-			     int            monitor,
-			     PanelOrient    orient,
-			     BasePMode      mode,
-			     BasePState     state,
-			     int            sz,
-			     gboolean       hidebuttons_enabled,
-			     gboolean       hidebutton_pixmap_enabled,
-			     PanelBackType  back_type,
-			     char          *back_pixmap,
-			     gboolean       fit_pixmap_bg,
-			     gboolean       stretch_pixmap_bg,
-			     gboolean       rotate_pixmap_bg,
-			     GdkColor      *back_color)
+drawer_widget_change_params (DrawerWidget        *drawer,
+			     int                  screen,
+			     int                  monitor,
+			     PanelOrient          orient,
+			     BasePMode            mode,
+			     BasePState           state,
+			     int                  sz,
+			     gboolean             hidebuttons_enabled,
+			     gboolean             hidebutton_pixmap_enabled,
+			     PanelBackgroundType  back_type,
+			     const char          *back_pixmap,
+			     gboolean             fit_pixmap_bg,
+			     gboolean             stretch_pixmap_bg,
+			     gboolean             rotate_pixmap_bg,
+			     PanelColor          *back_color)
 {
 	GtkOrientation porient;
 	DrawerPos *pos = DRAWER_POS (BASEP_WIDGET (drawer)->pos);
@@ -422,31 +421,31 @@ drawer_widget_change_orient (DrawerWidget *drawer,
 					     panel->sz,
 					     basep->hidebuttons_enabled,
 					     basep->hidebutton_pixmaps_enabled,
-					     panel->back_type,
-					     panel->back_pixmap,
-					     panel->fit_pixmap_bg,
-					     panel->stretch_pixmap_bg,
-					     panel->rotate_pixmap_bg,
-					     &panel->back_color);
+					     panel->background.type,
+					     panel->background.image,
+					     panel->background.fit_image,
+					     panel->background.stretch_image,
+					     panel->background.rotate_image,
+					     &panel->background.color);
 	}
 }
 
 GtkWidget *
-drawer_widget_new (char          *panel_id,
-		   int            screen,
-		   int            monitor,
-		   PanelOrient    orient,
-		   BasePMode      mode,
-		   BasePState     state,
-		   int            sz,
-		   gboolean       hidebuttons_enabled,
-		   gboolean       hidebutton_pixmap_enabled,
-		   PanelBackType  back_type,
-		   char          *back_pixmap,
-		   gboolean       fit_pixmap_bg,
-		   gboolean       stretch_pixmap_bg,
-		   gboolean       rotate_pixmap_bg,
-		   GdkColor      *back_color)
+drawer_widget_new (const char          *panel_id,
+		   int                  screen,
+		   int                  monitor,
+		   PanelOrient          orient,
+		   BasePMode            mode,
+		   BasePState           state,
+		   int                  sz,
+		   gboolean             hidebuttons_enabled,
+		   gboolean             hidebutton_pixmap_enabled,
+		   PanelBackgroundType  back_type,
+		   const char          *back_pixmap,
+		   gboolean             fit_pixmap_bg,
+		   gboolean             stretch_pixmap_bg,
+		   gboolean             rotate_pixmap_bg,
+		   PanelColor          *back_color)
 {
 	DrawerWidget *drawer;
 	DrawerPos *pos;
@@ -484,3 +483,16 @@ drawer_widget_new (char          *panel_id,
 				back_color);
 	return GTK_WIDGET (drawer);
 }
+
+void
+drawer_widget_set_drawer (DrawerWidget *widget,
+			  Drawer       *drawer)
+{
+	g_object_set_data (G_OBJECT (widget), "drawer-panel", drawer);
+}
+
+Drawer *
+drawer_widget_get_drawer (DrawerWidget *widget)
+{
+	return g_object_get_data (G_OBJECT (widget), "drawer-panel");
+}
