@@ -28,8 +28,8 @@
 #include "panel-config-global.h"
 #include "panel-shell.h"
 #include "session.h"
-#include "status.h"
 #include "xstuff.h"
+#include "panel-stock-icons.h"
 
 extern int config_sync_timeout;
 
@@ -51,6 +51,8 @@ char *kde_menudir = NULL;
 char *kde_icondir = NULL;
 char *kde_mini_icondir = NULL;
 
+GnomeIconTheme *panel_icon_theme = NULL;
+
 static gchar *profile_name;
 
 static gboolean
@@ -143,25 +145,6 @@ find_kde_directory (void)
 	kde_mini_icondir = g_strdup (KDE_MINI_ICONDIR);
 }
 
-static void
-kill_free_drawers (void)
-{
-	GSList *li;
-	GSList *to_destroy = NULL;
-	
-	for (li = panel_list; li != NULL; li = li->next) {
-		PanelData *pd = li->data;
-		if (DRAWER_IS_WIDGET (pd->panel) &&
-		    PANEL_WIDGET (BASEP_WIDGET (pd->panel)->panel)->master_widget == NULL) {
-			status_unparent (pd->panel);
-			to_destroy = g_slist_prepend (to_destroy, pd->panel);
-		}
-	}
-
-	g_slist_foreach (to_destroy, (GFunc)gtk_widget_destroy, NULL);
-	g_slist_free (to_destroy);
-}
-
 static const struct poptOption options[] = {
   {"profile", '\0', POPT_ARG_STRING, &profile_name, 0, N_("Specify a profile name to load"), NULL},
   POPT_AUTOHELP
@@ -189,6 +172,9 @@ main(int argc, char **argv)
 	
 	if (!panel_shell_register ())
 		return -1;
+
+	panel_icon_theme = gnome_icon_theme_new ();
+	
 	find_kde_directory();
 
 	client = gnome_master_client ();
@@ -206,17 +192,14 @@ main(int argc, char **argv)
 
 	xstuff_init ();
 	multiscreen_init ();
+	panel_init_stock_icons_and_items ();
 
 	panel_gconf_add_dir ("/apps/panel/global");
 	panel_gconf_add_dir ("/desktop/gnome/interface");
 	panel_gconf_notify_add ("/apps/panel/global", panel_global_config_notify, NULL);
 
-	status_applet_create_offscreen ();
-
 	session_load ();	
 
-	kill_free_drawers ();
-	
 	/*add forbidden lists to ALL panels*/
 	g_slist_foreach (panels,
 			 (GFunc)panel_widget_add_forbidden,
