@@ -38,6 +38,7 @@
 #include "session.h"
 #include "applet.h"
 #include "panel-marshal.h"
+#include "panel-background.h"
 
 #define HANDLE_SIZE 10
 
@@ -50,6 +51,7 @@ struct _PanelAppletFramePrivate {
 	Bonobo_PropertyBag              property_bag;
 	BonoboUIComponent              *ui_component;
 
+	PanelWidget                    *panel;
 	AppletInfo                     *applet_info;
 	PanelOrient                     orient;
 
@@ -128,18 +130,17 @@ popup_handle_move (BonoboUIComponent *uic,
 		   PanelAppletFrame  *frame,
 		   const gchar       *verbname)
 {
-	PanelWidget *panel;
-	GtkWidget   *widget;
+	GtkWidget *widget;
 
 	g_return_if_fail (GTK_IS_WIDGET (frame));
+	g_return_if_fail (PANEL_IS_WIDGET (frame->priv->panel));
 
 	widget = GTK_WIDGET (frame);
 
 	g_return_if_fail (PANEL_IS_WIDGET (widget->parent));
 
-	panel = PANEL_WIDGET (widget->parent);
-
-	panel_widget_applet_drag_start (panel, widget, PW_DRAG_OFF_CENTER);
+	panel_widget_applet_drag_start (
+		frame->priv->panel, widget, PW_DRAG_OFF_CENTER);
 }
 
 static BonoboUIVerb popup_verbs [] = {
@@ -276,54 +277,19 @@ panel_applet_frame_change_size (PanelAppletFrame *frame,
 }
 
 static char *
-panel_applet_frame_get_background_string (PanelAppletFrame *frame,
-					  PanelWidget      *panel,
-					  PanelBackType     type)
+panel_applet_frame_get_background_string (PanelAppletFrame    *frame,
+					  PanelWidget         *panel,
+					  PanelBackgroundType  type)
 {
-	char *retval = NULL;
-
-	switch (type) {
-	case PANEL_BACK_PIXMAP: {
-		GdkNativeWindow pixmap_xid;
-
-		/* If we don't actually have a pixmap background,
-		 * then don't force the applet to copy from our
-		 * window.
-		 */
-		if (!panel->background_pixmap)
-			return panel_applet_frame_get_background_string (
-					frame, panel, PANEL_BACK_NONE);
-
-		pixmap_xid = gdk_x11_drawable_get_xid (
-				GDK_DRAWABLE (panel->background_pixmap));
-
-		retval = g_strdup_printf (
-				"pixmap:%d,%d,%d", pixmap_xid,
-				GTK_WIDGET (frame)->allocation.x,
-				GTK_WIDGET (frame)->allocation.y);
-		}
-		break;
-	case PANEL_BACK_COLOR:
-		retval = g_strdup_printf (
-				"color:%.4x%.4x%.4x", 
-				panel->back_color.red, 
-				panel->back_color.green, 
-				panel->back_color.blue);
-		break;
-	case PANEL_BACK_NONE:
-		retval = g_strdup ("none:");
-		break;
-	default:
-		g_assert_not_reached ();
-		break;
-	}
-
-	return retval;
+	return panel_background_make_string (
+			&panel->background,
+			GTK_WIDGET (frame)->allocation.x,
+			GTK_WIDGET (frame)->allocation.y);
 }
 
 void
-panel_applet_frame_change_background (PanelAppletFrame *frame,
-				      PanelBackType     type)
+panel_applet_frame_change_background (PanelAppletFrame    *frame,
+				      PanelBackgroundType  type)
 {
 	char *bg_str;
 
@@ -434,9 +400,9 @@ panel_applet_frame_constrain_size (PanelAppletFrame *frame,
 {
 	PanelWidget *panel;
 
-	g_return_if_fail (PANEL_IS_WIDGET (GTK_WIDGET (frame)->parent));
+	g_return_if_fail (PANEL_IS_WIDGET (frame->priv->panel));
 
-	panel = PANEL_WIDGET (GTK_WIDGET (frame)->parent);
+	panel = frame->priv->panel;
 
 	switch (frame->priv->orient) {
 	case PANEL_ORIENT_UP:
@@ -608,17 +574,13 @@ panel_applet_frame_button_changed (GtkWidget      *widget,
 	case 1:
 	case 2:
 		if (button_event_in_rect (event, &frame->priv->handle_rect)) {
-			PanelWidget *panel;
-
-			panel = PANEL_WIDGET (GTK_WIDGET (frame)->parent);
-
 			if (event->type == GDK_BUTTON_PRESS ||
 			    event->type == GDK_2BUTTON_PRESS) {
 				panel_widget_applet_drag_start (
-					panel, GTK_WIDGET (frame), PW_DRAG_OFF_CURSOR);
+					frame->priv->panel, GTK_WIDGET (frame), PW_DRAG_OFF_CURSOR);
 				handled = TRUE;
 			} else if (event->type == GDK_BUTTON_RELEASE) {
-				panel_widget_applet_drag_end (panel);
+				panel_widget_applet_drag_end (frame->priv->panel);
 				handled = TRUE;
 			}
 		}
@@ -662,32 +624,32 @@ panel_applet_frame_reload_response (GtkWidget        *dialog,
 
 	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
 
-	if (!GTK_WIDGET (frame)->parent) {
-		g_object_unref (frame);
-		gtk_widget_destroy (dialog);
+	if (!frame->priv->iid || !frame->priv->panel)
 		return;
-	}
 
 	info = frame->priv->applet_info;
 
 	if (response == GTK_RESPONSE_YES) {
 		PanelWidget *panel;
 		char        *iid;
-		char        *gconf_key;
-		int          position;
+		char        *gconf_key = NULL;
+		int          position = -1;
 
-		panel     = PANEL_WIDGET (GTK_WIDGET (frame)->parent);
-		iid       = g_strdup (frame->priv->iid);
-		gconf_key = g_strdup (info->gconf_key);
-		position  = panel_applet_get_position (info);
+		panel = frame->priv->panel;
+		iid   = g_strdup (frame->priv->iid);
 
-		panel_applet_clean (info, FALSE);
+		if (info) {
+			gconf_key = g_strdup (info->gconf_key);
+			position  = panel_applet_get_position (info);
+			panel_applet_clean (info, FALSE);
+		}
 
 		panel_applet_frame_load (iid, panel, position, TRUE, gconf_key);
 
 		g_free (iid);
 		g_free (gconf_key);
-	} else
+
+	} else if (info)
 		panel_applet_clean (info, TRUE);
 
 	g_object_unref (frame);
@@ -735,16 +697,15 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 {
 	GtkWidget *dialog;
 	GdkScreen *screen;
-	char      *applet_name;
+	char      *applet_name = NULL;
 	char      *txt;
 
-	g_return_if_fail (frame->priv->applet_info != NULL);
+	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
 
-	screen = gtk_window_get_screen (
-			GTK_WINDOW (get_panel_parent (
-					frame->priv->applet_info->widget)));
+	screen = gtk_widget_get_screen (GTK_WIDGET (frame));
 
-	applet_name = panel_applet_frame_get_name (frame->priv->iid);
+	if (frame->priv->iid)
+		applet_name = panel_applet_frame_get_name (frame->priv->iid);
 
 	txt = g_strdup_printf (
 			_("The %s applet appears to have died "
@@ -869,6 +830,7 @@ panel_applet_frame_instance_init (PanelAppletFrame      *frame,
 	frame->priv->applet_shell     = CORBA_OBJECT_NIL;
 	frame->priv->property_bag     = CORBA_OBJECT_NIL;
 	frame->priv->ui_component     = NULL;
+	frame->priv->panel            = NULL;
 	frame->priv->orient           = PANEL_ORIENT_UP;
 	frame->priv->applet_info      = NULL;
 	frame->priv->moving_focus_out = FALSE;
@@ -998,7 +960,8 @@ panel_applet_frame_construct_moniker (PanelAppletFrame *frame,
 	char *retval;
 	char *bg_str;
 
-	bg_str = panel_applet_frame_get_background_string (frame, panel, panel->back_type);
+	bg_str = panel_applet_frame_get_background_string (
+				frame, panel, panel->background.type);
 
 	retval = g_strdup_printf (
 			"%s!prefs_key=/apps/panel/profiles/%s/applets/%s/prefs;"
@@ -1025,6 +988,8 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 	GtkWidget             *widget;
 	char                  *moniker;
 
+	frame->priv->panel = panel;
+
 	moniker = panel_applet_frame_construct_moniker (frame, panel, iid, gconf_key);
 
 	/* FIXME: this should really use bonobo_get_object_async */
@@ -1042,6 +1007,8 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 		return NULL;
 	}
 
+	frame->priv->iid = g_strdup (iid);
+
 	cnx_status = ORBit_small_get_connection_status (control);
 	if (cnx_status != ORBIT_CONNECTION_IN_PROC)
 		g_signal_connect_object (
@@ -1062,17 +1029,15 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 		return NULL;
 	}
 
-	frame->priv->iid = g_strdup (iid);
-
 	control_frame = bonobo_widget_get_control_frame (BONOBO_WIDGET (widget));
 
-	control = bonobo_control_frame_get_control (control_frame);
-
 	frame->priv->property_bag = 
 		bonobo_control_frame_get_control_property_bag (control_frame, NULL);
 
 	frame->priv->ui_component =
 		bonobo_control_frame_get_popup_component (control_frame, NULL);
+	if (!frame->priv->ui_component)
+		return NULL;
 
 	bonobo_ui_util_set_ui (frame->priv->ui_component, DATADIR,
 			       "GNOME_Panel_Popup.xml", "panel", NULL);
@@ -1080,6 +1045,10 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 	bonobo_ui_component_add_verb_list_with_data (
 		frame->priv->ui_component, popup_verbs, frame);
 
+	control = bonobo_control_frame_get_control (control_frame);
+	if (!control)
+		return NULL;
+
 	frame->priv->applet_shell = panel_applet_frame_get_applet_shell (control);
 
 	gtk_container_add (GTK_CONTAINER (frame), widget);
