@@ -36,6 +36,7 @@
 #include "menu-util.h"
 #include "panel-util.h"
 #include "panel-recent.h"
+#include "panel-stock-icons.h"
 
 /* FIXME: This code really should not be in the panel */
 static gboolean
@@ -170,6 +171,7 @@ panel_recent_append_documents_menu (GtkWidget *top_menu)
 			  screen);
 	egg_recent_view_gtk_show_numbers (view, FALSE);
 	egg_recent_view_set_model (EGG_RECENT_VIEW (view), model);
+	egg_recent_view_gtk_set_icon_size (view, panel_menu_icon_get_size ());
 	g_object_unref (G_OBJECT (model));
 
 	g_object_set_data_full (G_OBJECT (menu), "recent-view",
